translate.tools.podebug.podebug

Package translate :: Package tools :: Module podebug :: Class podebug |
[hide private]
[frames] | no frames]

# Class podebug

source code

Instance Methods | [hide private]
__init__(self, format=None, rewritestyle=None, ignoreoption=None) | source code
apply_to_translatables(self, string, func) Applies func to all translatable strings in string. | source code
_rewrite_prepend_append(self, string, prepend, append=None) | source code
rewrite_xxx(self, string) | source code
rewrite_bracket(self, string) | source code
rewrite_en(self, string) | source code
rewrite_blank(self, string) | source code
rewrite_chef(self, string) Rewrite using Mock Swedish as made famous by Monty Python | source code
rewrite_unicode(self, string) Convert to Unicode characters that look like the source string | source code
rewrite_flipped(self, string) Convert the string to look flipped upside down. | source code
ignore_openoffice(self, unit) | source code
ignore_mozilla(self, unit) | source code
ignore_gtk(self, unit) | source code
ignore_kde(self, unit) | source code
convertunit(self, unit, prefix) | source code
convertstore(self, store) | source code
shrinkfilename(self, filename) | source code

Class Methods | [hide private]
rewritelist(cls) | source code
ignorelist(cls) | source code

Class Variables | [hide private]
| REWRITE_UNICODE_MAP = `u"ȦƁƇḒḖƑƓĦĪĴĶĿḾȠǾƤɊŘŞŦŬṼẆẊẎẐ"+ u"[\\]^_``...``
| REWRITE_FLIPPED_MAP = `u"¡„#$%⅋,()⁎+´-˙/012Ɛᔭ59Ƚ86:;<=>¿@"+ u"∀`...``

Class Variable Details | [hide private]

  ### REWRITE_UNICODE_MAP Value:
      u"ȦƁƇḒḖƑƓĦĪĴĶĿḾȠǾƤɊŘŞŦŬṼẆẊẎẐ"+ u"[\\]^_`"+ u"ȧƀƈḓḗƒɠħīĵķŀḿƞǿƥɋřşŧŭṽẇẋẏ
      ẑ"

  ### REWRITE_FLIPPED_MAP Value:
      u"¡„#$%⅋,()⁎+´-˙/012Ɛᔭ59Ƚ86:;<=>¿@"+ u"∀ԐↃᗡƎℲ⅁HIſӼ⅂WNOԀÒᴚS⊥∩ɅＭX⅄Z"+ u"
      [\\]ᵥ_,"+ u"ɐqɔpǝɟƃɥıɾʞʅɯuodbɹsʇnʌʍxʎz"